==> haskell-success-0.2.6-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-Kb0khm687knBlZUYzqxbPS
key: success-0.2.6-Kb0khm687knBlZUYzqxbPS
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: c7db1031c1d526d522fd2deeb2885815
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.2/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.2/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/success-0.2.6
hs-libraries: HSsuccess-0.2.6-Kb0khm687knBlZUYzqxbPS
depends:
    transformers-base-0.4.5.2-B43Gv9BQzaL3TVuXdqmztg
    monad-control-1.0.2.3-JSGt4lf3bgHBDGzRIRMMyB mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-B43Gv9BQzaL3TVuXdqmztg=81fed98938a0cfae65316abd9f062c0f
             monad-control-1.0.2.3-JSGt4lf3bgHBDGzRIRMMyB=48d0200a910e09bfb736f1d444daf640
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-3a3eCydyoxxJgiPQwHPBQ9
key: success-0.2.6-3a3eCydyoxxJgiPQwHPBQ9
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 2eaf026d39fdbbe388329cb7a708a34a
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-3a3eCydyoxxJgiPQwHPBQ9
depends:
    transformers-base-0.4.5.2-KW6dpmOXA8I95CecmuGvJB
    monad-control-1.0.2.3-1gGLH28moKUENbl4ouk61u mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-KW6dpmOXA8I95CecmuGvJB=a3b4f976cb4fc5cdc4f30a5f5505a094
             monad-control-1.0.2.3-1gGLH28moKUENbl4ouk61u=7e3faadfd44887e2bf15143780118087
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
